pub struct CredentialSpendingData {
pub payment: Payment,
pub pay_info: PayInfo,
pub spend_date: Date,
pub epoch_id: u64,
}Fields
payment: Paymentpay_info: PayInfospend_date: Dateepoch_id: u64The (DKG) epoch id under which the credential has been issued so that the verifier could use correct verification key for validation.