pub struct EcashSignerStatusResponseBody {
pub current_time: OffsetDateTime,
pub dkg_ecash_epoch_id: EpochId,
pub signer_disabled: bool,
pub is_ecash_signer: bool,
pub has_signing_keys: bool,
}Fields
current_time: OffsetDateTimedkg_ecash_epoch_id: EpochIdCurrent, perceived, dkg epoch id
signer_disabled: boolFlag indicating whether the operator has explicitly disabled signer functionalities in the api
is_ecash_signer: boolFlag indicating whether this api thinks it’s a valid ecash signer for the current epoch
has_signing_keys: boolFlag indicating whether this api thinks it has valid signing keys. It might be a valid signer that’s not disabled, but the keys might have accidentally been removed due to invalid data migration.