pub struct IssuedTicketbooksChallengeCommitmentResponseBody {
pub expiration_date: Date,
pub original_request: IssuedTicketbooksChallengeCommitmentRequest,
pub max_data_response_size: usize,
pub merkle_proof: IssuedTicketbooksFullMerkleProof,
}Fields
expiration_date: Dateoriginal_request: IssuedTicketbooksChallengeCommitmentRequestmax_data_response_size: usizeIndicate the maximum number of entries that can be returned at once when asking for ticketbook data
merkle_proof: IssuedTicketbooksFullMerkleProofTrait Implementations
Sourceimpl Clone for IssuedTicketbooksChallengeCommitmentResponseBody
impl Clone for IssuedTicketbooksChallengeCommitmentResponseBody
Sourcefn clone(&self) -> IssuedTicketbooksChallengeCommitmentResponseBody
fn clone(&self) -> IssuedTicketbooksChallengeCommitmentResponseBody
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for IssuedTicketbooksChallengeCommitmentResponseBody
impl ComposeSchema for IssuedTicketbooksChallengeCommitmentResponseBody
Sourceimpl<'de> Deserialize<'de> for IssuedTicketbooksChallengeCommitmentResponseBody
impl<'de> Deserialize<'de> for IssuedTicketbooksChallengeCommitmentResponseBody
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more