pub struct SignerInformationResponse {
pub cosmos_address: String,
pub identity: String,
pub announce_address: String,
pub verification_key: Option<String>,
}Fields
cosmos_address: Stringidentity: Stringannounce_address: Stringverification_key: Option<String>Trait Implementations
Sourceimpl Clone for SignerInformationResponse
impl Clone for SignerInformationResponse
Sourcefn clone(&self) -> SignerInformationResponse
fn clone(&self) -> SignerInformationResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for SignerInformationResponse
impl ComposeSchema for SignerInformationResponse
Sourceimpl Debug for SignerInformationResponse
impl Debug for SignerInformationResponse
Sourceimpl<'de> Deserialize<'de> for SignerInformationResponse
impl<'de> Deserialize<'de> for SignerInformationResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SignerInformationResponse
impl JsonSchema for SignerInformationResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SignerInformationResponse
impl RefUnwindSafe for SignerInformationResponse
impl Send for SignerInformationResponse
impl Sync for SignerInformationResponse
impl Unpin for SignerInformationResponse
impl UnwindSafe for SignerInformationResponse