pub struct HostInformation {
pub ip_address: Vec<IpAddr>,
pub hostname: Option<String>,
pub keys: HostKeys,
}Fields
ip_address: Vec<IpAddr>hostname: Option<String>keys: HostKeysTrait Implementations
Sourceimpl Clone for HostInformation
impl Clone for HostInformation
Sourcefn clone(&self) -> HostInformation
fn clone(&self) -> HostInformation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for HostInformation
impl ComposeSchema for HostInformation
Sourceimpl Debug for HostInformation
impl Debug for HostInformation
Sourceimpl<'de> Deserialize<'de> for HostInformation
impl<'de> Deserialize<'de> for HostInformation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<HostInformation> for HostInformation
impl From<HostInformation> for HostInformation
Sourcefn from(value: HostInformation) -> Self
fn from(value: HostInformation) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for HostInformation
impl JsonSchema for HostInformation
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for HostInformation
impl Serialize for HostInformation