pub struct WireguardDetails {
pub port: u16,
pub tunnel_port: u16,
pub metadata_port: u16,
pub public_key: String,
}Fields
port: u16tunnel_port: u16metadata_port: u16public_key: StringTrait Implementations
Sourceimpl Clone for WireguardDetails
impl Clone for WireguardDetails
Sourcefn clone(&self) -> WireguardDetails
fn clone(&self) -> WireguardDetails
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for WireguardDetails
impl ComposeSchema for WireguardDetails
Sourceimpl Debug for WireguardDetails
impl Debug for WireguardDetails
Sourceimpl<'de> Deserialize<'de> for WireguardDetails
impl<'de> Deserialize<'de> for WireguardDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Wireguard> for WireguardDetails
impl From<Wireguard> for WireguardDetails
Sourceimpl JsonSchema for WireguardDetails
impl JsonSchema for WireguardDetails
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for WireguardDetails
impl Serialize for WireguardDetails