pub struct KeyRotationProgressInfo {
pub current_key_rotation_id: u32,
pub current_rotation_starting_epoch: u32,
pub current_rotation_ending_epoch: u32,
}Fields
current_key_rotation_id: u32current_rotation_starting_epoch: u32current_rotation_ending_epoch: u32Trait Implementations
Sourceimpl Clone for KeyRotationProgressInfo
impl Clone for KeyRotationProgressInfo
Sourcefn clone(&self) -> KeyRotationProgressInfo
fn clone(&self) -> KeyRotationProgressInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for KeyRotationProgressInfo
impl ComposeSchema for KeyRotationProgressInfo
Sourceimpl Debug for KeyRotationProgressInfo
impl Debug for KeyRotationProgressInfo
Sourceimpl<'de> Deserialize<'de> for KeyRotationProgressInfo
impl<'de> Deserialize<'de> for KeyRotationProgressInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KeyRotationProgressInfo
impl JsonSchema for KeyRotationProgressInfo
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for KeyRotationProgressInfo
impl Serialize for KeyRotationProgressInfo
Sourceimpl ToSchema for KeyRotationProgressInfo
impl ToSchema for KeyRotationProgressInfo
impl Copy for KeyRotationProgressInfo