pub struct RewardedSetResponse {
pub epoch_id: EpochId,
pub entry_gateways: Vec<NodeId>,
pub exit_gateways: Vec<NodeId>,
pub layer1: Vec<NodeId>,
pub layer2: Vec<NodeId>,
pub layer3: Vec<NodeId>,
pub standby: Vec<NodeId>,
}Fields
epoch_id: EpochIdentry_gateways: Vec<NodeId>exit_gateways: Vec<NodeId>layer1: Vec<NodeId>layer2: Vec<NodeId>layer3: Vec<NodeId>standby: Vec<NodeId>Trait Implementations
Sourceimpl Clone for RewardedSetResponse
impl Clone for RewardedSetResponse
Sourcefn clone(&self) -> RewardedSetResponse
fn clone(&self) -> RewardedSetResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for RewardedSetResponse
impl ComposeSchema for RewardedSetResponse
Sourceimpl Debug for RewardedSetResponse
impl Debug for RewardedSetResponse
Sourceimpl<'de> Deserialize<'de> for RewardedSetResponse
impl<'de> Deserialize<'de> for RewardedSetResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<EpochRewardedSet> for RewardedSetResponse
impl From<EpochRewardedSet> for RewardedSetResponse
Sourcefn from(r: EpochRewardedSet) -> Self
fn from(r: EpochRewardedSet) -> Self
Converts to this type from the input type.
Sourceimpl From<RewardedSetResponse> for EpochRewardedSet
impl From<RewardedSetResponse> for EpochRewardedSet
Sourcefn from(res: RewardedSetResponse) -> Self
fn from(res: RewardedSetResponse) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for RewardedSetResponse
impl JsonSchema for RewardedSetResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for RewardedSetResponse
impl Serialize for RewardedSetResponse