pub struct ChainStatusResponse {
pub connected_nyxd: String,
pub status: DetailedChainStatus,
}Fields
connected_nyxd: Stringstatus: DetailedChainStatusTrait Implementations
Sourceimpl Clone for ChainStatusResponse
impl Clone for ChainStatusResponse
Sourcefn clone(&self) -> ChainStatusResponse
fn clone(&self) -> ChainStatusResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ChainStatusResponse
impl ComposeSchema for ChainStatusResponse
Sourceimpl Debug for ChainStatusResponse
impl Debug for ChainStatusResponse
Sourceimpl<'de> Deserialize<'de> for ChainStatusResponse
impl<'de> Deserialize<'de> for ChainStatusResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChainStatusResponse
impl JsonSchema for ChainStatusResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl LegacyChainResponse for ChainStatusResponse
impl LegacyChainResponse for ChainStatusResponse
fn chain_synced(&self, now: OffsetDateTime, stall_threshold: Duration) -> bool
Sourceimpl Serialize for ChainStatusResponse
impl Serialize for ChainStatusResponse