pub struct MixnodeCoreStatusResponse {
pub mix_id: NodeId,
pub count: i64,
}Fields
mix_id: NodeIdcount: i64Trait Implementations
Sourceimpl Clone for MixnodeCoreStatusResponse
impl Clone for MixnodeCoreStatusResponse
Sourcefn clone(&self) -> MixnodeCoreStatusResponse
fn clone(&self) -> MixnodeCoreStatusResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for MixnodeCoreStatusResponse
impl ComposeSchema for MixnodeCoreStatusResponse
Sourceimpl Debug for MixnodeCoreStatusResponse
impl Debug for MixnodeCoreStatusResponse
Sourceimpl<'de> Deserialize<'de> for MixnodeCoreStatusResponse
impl<'de> Deserialize<'de> for MixnodeCoreStatusResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MixnodeCoreStatusResponse
impl JsonSchema for MixnodeCoreStatusResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MixnodeCoreStatusResponse
impl RefUnwindSafe for MixnodeCoreStatusResponse
impl Send for MixnodeCoreStatusResponse
impl Sync for MixnodeCoreStatusResponse
impl Unpin for MixnodeCoreStatusResponse
impl UnwindSafe for MixnodeCoreStatusResponse