pub struct OutdatedVersionWeights {
pub major: u32,
pub minor: u32,
pub patch: u32,
pub prerelease: u32,
}Expand description
Defines weights for calculating numbers of versions behind the current release.
Fields
major: u32minor: u32patch: u32prerelease: u32Trait Implementations
Sourceimpl Clone for OutdatedVersionWeights
impl Clone for OutdatedVersionWeights
Sourcefn clone(&self) -> OutdatedVersionWeights
fn clone(&self) -> OutdatedVersionWeights
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for OutdatedVersionWeights
impl ComposeSchema for OutdatedVersionWeights
Sourceimpl Debug for OutdatedVersionWeights
impl Debug for OutdatedVersionWeights
Sourceimpl<'de> Deserialize<'de> for OutdatedVersionWeights
impl<'de> Deserialize<'de> for OutdatedVersionWeights
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<OutdatedVersionWeights> for OutdatedVersionWeights
impl From<OutdatedVersionWeights> for OutdatedVersionWeights
Sourcefn from(value: OutdatedVersionWeights) -> Self
fn from(value: OutdatedVersionWeights) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for OutdatedVersionWeights
impl JsonSchema for OutdatedVersionWeights
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for OutdatedVersionWeights
impl Serialize for OutdatedVersionWeights