pub struct AnnotationResponse {
pub node_id: NodeId,
pub annotation: Option<NodeAnnotation>,
}Fields
node_id: NodeIdannotation: Option<NodeAnnotation>Trait Implementations
Sourceimpl Clone for AnnotationResponse
impl Clone for AnnotationResponse
Sourcefn clone(&self) -> AnnotationResponse
fn clone(&self) -> AnnotationResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for AnnotationResponse
impl ComposeSchema for AnnotationResponse
Sourceimpl Debug for AnnotationResponse
impl Debug for AnnotationResponse
Sourceimpl<'de> Deserialize<'de> for AnnotationResponse
impl<'de> Deserialize<'de> for AnnotationResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AnnotationResponse
impl JsonSchema for AnnotationResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for AnnotationResponse
impl Serialize for AnnotationResponse
Sourceimpl ToSchema for AnnotationResponse
impl ToSchema for AnnotationResponse
impl Copy for AnnotationResponse