pub struct AnnotationResponseV2 {
pub node_id: NodeId,
pub annotation: Option<NodeAnnotationV2>,
}Fields
node_id: NodeIdannotation: Option<NodeAnnotationV2>Trait Implementations
Sourceimpl Clone for AnnotationResponseV2
impl Clone for AnnotationResponseV2
Sourcefn clone(&self) -> AnnotationResponseV2
fn clone(&self) -> AnnotationResponseV2
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for AnnotationResponseV2
impl ComposeSchema for AnnotationResponseV2
Sourceimpl Debug for AnnotationResponseV2
impl Debug for AnnotationResponseV2
Sourceimpl<'de> Deserialize<'de> for AnnotationResponseV2
impl<'de> Deserialize<'de> for AnnotationResponseV2
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AnnotationResponseV2
impl JsonSchema for AnnotationResponseV2
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for AnnotationResponseV2
impl Serialize for AnnotationResponseV2