#[non_exhaustive]pub struct ConfigScoreV1 {
pub score: f64,
pub versions_behind: Option<u32>,
pub self_described_api_available: bool,
pub accepted_terms_and_conditions: bool,
pub runs_nym_node_binary: bool,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.score: f64Total score after taking all the criteria into consideration
versions_behind: Option<u32>self_described_api_available: boolaccepted_terms_and_conditions: boolruns_nym_node_binary: boolTrait Implementations
Sourceimpl Clone for ConfigScoreV1
impl Clone for ConfigScoreV1
Sourcefn clone(&self) -> ConfigScoreV1
fn clone(&self) -> ConfigScoreV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for ConfigScoreV1
impl ComposeSchema for ConfigScoreV1
impl Copy for ConfigScoreV1
Sourceimpl Debug for ConfigScoreV1
impl Debug for ConfigScoreV1
Sourceimpl Default for ConfigScoreV1
impl Default for ConfigScoreV1
Sourcefn default() -> ConfigScoreV1
fn default() -> ConfigScoreV1
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ConfigScoreV1
impl<'de> Deserialize<'de> for ConfigScoreV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ConfigScoreV2> for ConfigScoreV1
impl From<ConfigScoreV2> for ConfigScoreV1
Sourcefn from(score_v2: ConfigScoreV2) -> ConfigScoreV1
fn from(score_v2: ConfigScoreV2) -> ConfigScoreV1
Converts to this type from the input type.
Sourceimpl JsonSchema for ConfigScoreV1
impl JsonSchema for ConfigScoreV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ConfigScoreV1
impl Serialize for ConfigScoreV1