pub struct GatewayStatusReportResponse {
pub identity: String,
pub owner: String,
pub most_recent: u8,
pub last_hour: u8,
pub last_day: u8,
}Fields
identity: Stringowner: Stringmost_recent: u8last_hour: u8last_day: u8Trait Implementations
Sourceimpl Clone for GatewayStatusReportResponse
impl Clone for GatewayStatusReportResponse
Sourcefn clone(&self) -> GatewayStatusReportResponse
fn clone(&self) -> GatewayStatusReportResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for GatewayStatusReportResponse
impl ComposeSchema for GatewayStatusReportResponse
Sourceimpl<'de> Deserialize<'de> for GatewayStatusReportResponse
impl<'de> Deserialize<'de> for GatewayStatusReportResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GatewayStatusReportResponse
impl JsonSchema for GatewayStatusReportResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GatewayStatusReportResponse
impl RefUnwindSafe for GatewayStatusReportResponse
impl Send for GatewayStatusReportResponse
impl Sync for GatewayStatusReportResponse
impl Unpin for GatewayStatusReportResponse
impl UnwindSafe for GatewayStatusReportResponse