pub struct GatewayUptimeResponse {
pub identity: String,
pub avg_uptime: u8,
pub node_performance: NodePerformance,
}Fields
identity: Stringavg_uptime: u8node_performance: NodePerformanceTrait Implementations
Sourceimpl Clone for GatewayUptimeResponse
impl Clone for GatewayUptimeResponse
Sourcefn clone(&self) -> GatewayUptimeResponse
fn clone(&self) -> GatewayUptimeResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for GatewayUptimeResponse
impl ComposeSchema for GatewayUptimeResponse
Sourceimpl Debug for GatewayUptimeResponse
impl Debug for GatewayUptimeResponse
Sourceimpl<'de> Deserialize<'de> for GatewayUptimeResponse
impl<'de> Deserialize<'de> for GatewayUptimeResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GatewayUptimeResponse
impl JsonSchema for GatewayUptimeResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for GatewayUptimeResponse
impl Serialize for GatewayUptimeResponse