pub struct NodeAnnotation {
pub last_24h_performance: Performance,
pub current_role: Option<DisplayRole>,
pub detailed_performance: DetailedNodePerformance,
}Fields
last_24h_performance: Performancecurrent_role: Option<DisplayRole>detailed_performance: DetailedNodePerformanceTrait Implementations
Sourceimpl Clone for NodeAnnotation
impl Clone for NodeAnnotation
Sourcefn clone(&self) -> NodeAnnotation
fn clone(&self) -> NodeAnnotation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for NodeAnnotation
impl ComposeSchema for NodeAnnotation
Sourceimpl Debug for NodeAnnotation
impl Debug for NodeAnnotation
Sourceimpl Default for NodeAnnotation
impl Default for NodeAnnotation
Sourcefn default() -> NodeAnnotation
fn default() -> NodeAnnotation
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for NodeAnnotation
impl<'de> Deserialize<'de> for NodeAnnotation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NodeAnnotation
impl JsonSchema for NodeAnnotation
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for NodeAnnotation
impl Serialize for NodeAnnotation
Sourceimpl ToSchema for NodeAnnotation
impl ToSchema for NodeAnnotation
impl Copy for NodeAnnotation