pub struct NodeAnnotationV1 {
pub last_24h_performance: Performance,
pub current_role: Option<DisplayRole>,
pub detailed_performance: DetailedNodePerformanceV1,
}Fields
last_24h_performance: Performancecurrent_role: Option<DisplayRole>detailed_performance: DetailedNodePerformanceV1Trait Implementations
Sourceimpl Clone for NodeAnnotationV1
impl Clone for NodeAnnotationV1
Sourcefn clone(&self) -> NodeAnnotationV1
fn clone(&self) -> NodeAnnotationV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for NodeAnnotationV1
impl ComposeSchema for NodeAnnotationV1
impl Copy for NodeAnnotationV1
Sourceimpl Debug for NodeAnnotationV1
impl Debug for NodeAnnotationV1
Sourceimpl Default for NodeAnnotationV1
impl Default for NodeAnnotationV1
Sourcefn default() -> NodeAnnotationV1
fn default() -> NodeAnnotationV1
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for NodeAnnotationV1
impl<'de> Deserialize<'de> for NodeAnnotationV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<NodeAnnotationV2> for NodeAnnotationV1
impl From<NodeAnnotationV2> for NodeAnnotationV1
Sourcefn from(value: NodeAnnotationV2) -> Self
fn from(value: NodeAnnotationV2) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for NodeAnnotationV1
impl JsonSchema for NodeAnnotationV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for NodeAnnotationV1
impl Serialize for NodeAnnotationV1