pub struct NodeDatePerformanceResponse {
pub node_id: NodeId,
pub date: Date,
pub performance: Option<f64>,
}Fields
node_id: NodeIddate: Dateperformance: Option<f64>Trait Implementations
Sourceimpl Clone for NodeDatePerformanceResponse
impl Clone for NodeDatePerformanceResponse
Sourcefn clone(&self) -> NodeDatePerformanceResponse
fn clone(&self) -> NodeDatePerformanceResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for NodeDatePerformanceResponse
impl ComposeSchema for NodeDatePerformanceResponse
Sourceimpl Debug for NodeDatePerformanceResponse
impl Debug for NodeDatePerformanceResponse
Sourceimpl<'de> Deserialize<'de> for NodeDatePerformanceResponse
impl<'de> Deserialize<'de> for NodeDatePerformanceResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NodeDatePerformanceResponse
impl JsonSchema for NodeDatePerformanceResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl Copy for NodeDatePerformanceResponse