pub struct NodePerformance {
pub most_recent: Performance,
pub last_hour: Performance,
pub last_24h: Performance,
}Fields
most_recent: Performancelast_hour: Performancelast_24h: PerformanceTrait Implementations
Sourceimpl Clone for NodePerformance
impl Clone for NodePerformance
Sourcefn clone(&self) -> NodePerformance
fn clone(&self) -> NodePerformance
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for NodePerformance
impl ComposeSchema for NodePerformance
Sourceimpl Debug for NodePerformance
impl Debug for NodePerformance
Sourceimpl Default for NodePerformance
impl Default for NodePerformance
Sourcefn default() -> NodePerformance
fn default() -> NodePerformance
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for NodePerformance
impl<'de> Deserialize<'de> for NodePerformance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NodePerformance
impl JsonSchema for NodePerformance
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for NodePerformance
impl Serialize for NodePerformance