pub struct NodePerformanceResponse {
pub node_id: NodeId,
pub performance: Option<f64>,
}Fields
node_id: NodeIdperformance: Option<f64>Trait Implementations
Sourceimpl Clone for NodePerformanceResponse
impl Clone for NodePerformanceResponse
Sourcefn clone(&self) -> NodePerformanceResponse
fn clone(&self) -> NodePerformanceResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for NodePerformanceResponse
impl ComposeSchema for NodePerformanceResponse
Sourceimpl Debug for NodePerformanceResponse
impl Debug for NodePerformanceResponse
Sourceimpl<'de> Deserialize<'de> for NodePerformanceResponse
impl<'de> Deserialize<'de> for NodePerformanceResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NodePerformanceResponse
impl JsonSchema for NodePerformanceResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for NodePerformanceResponse
impl Serialize for NodePerformanceResponse
Sourceimpl ToSchema for NodePerformanceResponse
impl ToSchema for NodePerformanceResponse
impl Copy for NodePerformanceResponse