pub struct StakeSaturationResponse {
pub saturation: StakeSaturation,
pub uncapped_saturation: StakeSaturation,
pub as_at: i64,
}Fields
saturation: StakeSaturationuncapped_saturation: StakeSaturationas_at: i64Trait Implementations
Sourceimpl Clone for StakeSaturationResponse
impl Clone for StakeSaturationResponse
Sourcefn clone(&self) -> StakeSaturationResponse
fn clone(&self) -> StakeSaturationResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for StakeSaturationResponse
impl ComposeSchema for StakeSaturationResponse
Sourceimpl Debug for StakeSaturationResponse
impl Debug for StakeSaturationResponse
Sourceimpl<'de> Deserialize<'de> for StakeSaturationResponse
impl<'de> Deserialize<'de> for StakeSaturationResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StakeSaturationResponse
impl JsonSchema for StakeSaturationResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for StakeSaturationResponse
impl Serialize for StakeSaturationResponse
Sourceimpl ToSchema for StakeSaturationResponse
impl ToSchema for StakeSaturationResponse
impl Copy for StakeSaturationResponse