pub struct KeyRotationState {
pub validity_epochs: u32,
pub initial_epoch_id: u32,
}Fields
validity_epochs: u32Defines how long each key rotation is valid for (in terms of epochs)
initial_epoch_id: u32Records the initial epoch_id when the key rotation has been introduced (0 for fresh contracts). It is used for determining when rotation is meant to advance.
Implementations
Sourceimpl KeyRotationState
impl KeyRotationState
pub fn key_rotation_id(&self, current_epoch_id: u32) -> u32
pub fn next_rotation_starting_epoch_id(&self, current_epoch_id: u32) -> u32
pub fn current_rotation_starting_epoch_id(&self, current_epoch_id: u32) -> u32