pub struct VersionedNoiseKey {
pub supported_version: NoiseVersion,
pub x25519_pubkey: PublicKey,
}Fields
supported_version: NoiseVersionx25519_pubkey: PublicKeyTrait Implementations
Sourceimpl Clone for VersionedNoiseKey
impl Clone for VersionedNoiseKey
Sourcefn clone(&self) -> VersionedNoiseKey
fn clone(&self) -> VersionedNoiseKey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VersionedNoiseKey
impl Debug for VersionedNoiseKey
Sourceimpl<'de> Deserialize<'de> for VersionedNoiseKey
impl<'de> Deserialize<'de> for VersionedNoiseKey
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<VersionedNoiseKey, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<VersionedNoiseKey, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VersionedNoiseKey
impl JsonSchema for VersionedNoiseKey
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for VersionedNoiseKey
impl Serialize for VersionedNoiseKey
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl ToSchema for VersionedNoiseKey
impl ToSchema for VersionedNoiseKey
impl Copy for VersionedNoiseKey