pub struct FullFatNode {
pub expanded: SemiSkimmedNode,
pub self_described: Option<NymNodeData>,
}Fields
expanded: SemiSkimmedNodeself_described: Option<NymNodeData>Trait Implementations
Sourceimpl Clone for FullFatNode
impl Clone for FullFatNode
Sourcefn clone(&self) -> FullFatNode
fn clone(&self) -> FullFatNode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for FullFatNode
impl ComposeSchema for FullFatNode
Sourceimpl Debug for FullFatNode
impl Debug for FullFatNode
Sourceimpl<'de> Deserialize<'de> for FullFatNode
impl<'de> Deserialize<'de> for FullFatNode
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FullFatNode
impl JsonSchema for FullFatNode
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for FullFatNode
impl Serialize for FullFatNode